"use strict";
const fetch_1 = require("../http/fetch");
const searchParamsValidation_1 = require("../validation/searchParamsValidation");
const index_1 = require("../strategies/index");
function createResolver(...args) {
    const resolveStrategyFactories = resolveOverride();
    return {
        resolveDependencyUrl
    };
    function resolveOverride() {
        if (args.length === 0) {
            return [index_1.default];
        }
        if (args[0] instanceof Array) {
            return args[0];
        }
        return args;
    }
    function resolveDependencyUrl(search) {
        searchParamsValidation_1.validateSearchParams(search);
        const resolveStrategyIterator = getResolveStrategyIterator(search);
        return recursiveResolveDependencyUrl(resolveStrategyIterator);
    }
    function* getResolveStrategyIterator(search) {
        for (let createStrategy of resolveStrategyFactories) {
            yield createStrategy(search);
        }
    }
    function recursiveResolveDependencyUrl(resolveStrategyIterator, previousSearchResult, previousError) {
        const resolveStrategyIteratorResult = resolveStrategyIterator.next();
        if (resolveStrategyIteratorResult.done) {
            return onNoResult();
        }
        return resolveDependencyUrlWithStrategy(resolveStrategyIteratorResult.value)
            .then(onSuccess)
            .catch(onError);
        function onNoResult() {
            if (previousSearchResult) {
                return Promise.resolve(previousSearchResult);
            }
            return Promise.reject(previousError);
        }
        function onSuccess(result) {
            return result.url
                ? result
                : recursiveResolveDependencyUrl(resolveStrategyIterator, result);
        }
        function onError(error) {
            return recursiveResolveDependencyUrl(resolveStrategyIterator, null, error);
        }
    }
    function resolveDependencyUrlWithStrategy(resolveStrategy) {
        return fetch_1.fetch(resolveStrategy.getUrl())
            .then(resolveStrategy.getResult);
    }
}
exports.createResolver = createResolver;
//# sourceMappingURL=resolver.js.map