'use strict';
const semver = require("semver");
const SearchResult = require("../dto/SearchResult");
const baseUrl = 'https://api.cdnjs.com/libraries';
function createCdnJsStrategy(search) {
    return {
        getUrl,
        getResult
    };
    function getUrl() {
        return `${baseUrl}?search=${search.name}&fields=version,assets`;
    }
    function getResult({ results }) {
        let url;
        const result = results.find(isSearchNameEqual);
        if (result) {
            const asset = getMaxSatisfyingAsset(result.assets, search.versionRange);
            if (asset) {
                const latestVersion = result.version;
                url = result.latest.replace(latestVersion, asset.version);
            }
        }
        return SearchResult.fromSearch(search, url);
    }
    function isSearchNameEqual(result) {
        return search.name === result.name;
    }
}
exports.createCdnJsStrategy = createCdnJsStrategy;
function getMaxSatisfyingAsset(assets, versionRange) {
    const validAssetsVersions = assets.map((a) => a.version).filter(semver.valid);
    const maxSatisfyingVersion = semver.maxSatisfying(validAssetsVersions, versionRange);
    return assets.find((a) => a.version === maxSatisfyingVersion);
}
//# sourceMappingURL=cdnJsResolveStrategy.js.map